@@ -2,7 +2,7 @@ from enum import Enum, unique
 
 
 BLANK_LINE_TOKEN = "TOKEN"
-BLANK_LINES_TYPES = ["arglist", "expr_stmt", "atom_expr"]
+BLANK_LINES_TYPES = ["arglist", "expr_stmt", "atom_expr", "atom"]
 COMPREHENSIONS_TYPES = ["comp_if", "sync_comp_for"]
 TYPES_TO_CHECK_FMT_ON_OFF = ("stmt", "funcdef", "classdef")
 MAX_CHARACTERS_TO_FIND_INDENTATION_PARENT = 200
